==> xlniuxdata-vipgame-1.0.65-20170705.065901-90-sources.jar: com/xunlei/niux/data/vipgame/vo/sendgift/GameSendGiftJinzuan.java <==
package com.xunlei.niux.data.vipgame.vo.sendgift;

import com.ferret.common.dao.annotation.Table;

/**
 * Created by admin on 2017/6/14.
 */
@Table(tableName = "game_send_gift_jinzuan", pkFieldName = "seqId", pkFieldAssign = false)
public class GameSendGiftJinzuan {

    /**
     * 年费会员
     */
    public static final  String JINZUAN_LEVEL_ANNUALMEMBER="100";

    /**
     * 专属称号
     */
    public static final  String JINZUAN_LEVEL_EXCLUSIVE="101";

    /**
     * 领取等级
     */
    public static final String GIFT_TYPE_LEVEL="level";
    /**
     * 领取年费
     */
    public static final String GIFT_TYPE_ANNUAL="annual";
    /**
     * 领取专属
     */
    public static final String GIFT_TYPE_EXCLUSIVE="exclusive";



    private Integer seqId;
    private String  gameId;
    private String  giftId;
    /**
     * 物品内容
     */
    private String  items;
    /**
     * 金钻等级1~7级,100：年费专属
     */
    private String  jinzuanLevel;

    private String inputBy;
    private String inputTime;
    private String editBy;
    private String editTime;

    public Integer getSeqId() {
        return seqId;
    }

    public void setSeqId(Integer seqId) {
        this.seqId = seqId;
    }

    public String getGameId() {
        return gameId;
    }

    public void setGameId(String gameId) {
        this.gameId = gameId;
    }

    public String getGiftId() {
        return giftId;
    }

    public void setGiftId(String giftId) {
        this.giftId = giftId;
    }

    public String getItems() {
        return items;
    }

    public void setItems(String items) {
        this.items = items;
    }

    public String getJinzuanLevel() {
        return jinzuanLevel;
    }

    public void setJinzuanLevel(String jinzuanLevel) {
        this.jinzuanLevel = jinzuanLevel;
    }

    public String getInputBy() {
        return inputBy;
    }

    public void setInputBy(String inputBy) {
        this.inputBy = inputBy;
    }

    public String getInputTime() {
        return inputTime;
    }

    public void setInputTime(String inputTime) {
        this.inputTime = inputTime;
    }

    public String getEditBy() {
        return editBy;
    }

    public void setEditBy(String editBy) {
        this.editBy = editBy;
    }

    public String getEditTime() {
        return editTime;
    }

    public void setEditTime(String editTime) {
        this.editTime = editTime;
    }


}

==> xlniuxdata-vipgame-1.0.65-20170905.092047-106-sources.jar: com/xunlei/niux/data/vipgame/vo/sendgift/GameSendGiftJinzuan.java <==
package com.xunlei.niux.data.vipgame.vo.sendgift;

import com.ferret.common.dao.annotation.Table;

/**
 * Created by admin on 2017/6/14.
 */
@Table(tableName = "game_send_gift_jinzuan", pkFieldName = "seqId", pkFieldAssign = false)
public class GameSendGiftJinzuan {

    /**
     * 年费会员
     */
    public static final  String JINZUAN_LEVEL_ANNUALMEMBER="100";

    /**
     * 专属称号
     */
    public static final  String JINZUAN_LEVEL_EXCLUSIVE="101";

    /**
     * 领取等级
     */
    public static final String GIFT_TYPE_LEVEL="level";
    /**
     * 领取年费
     */
    public static final String GIFT_TYPE_ANNUAL="annual";
    /**
     * 领取专属
     */
    public static final String GIFT_TYPE_EXCLUSIVE="exclusive";



    private Integer seqId;
    private String  gameId;
    private String  giftId;

    /**
     * 物品内容

     */
    private String  items;

    /**
     * 金钻等级1~7级,100：年费专属
     */
    private String  jinzuanLevel;
    private String inputBy;

    private String inputTime;
    private String editBy;
    private String editTime;
    private Integer status;
    public Integer getSeqId() {
        return seqId;
    }

    public void setSeqId(Integer seqId) {
        this.seqId = seqId;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public String getGameId() {
        return gameId;
    }

    public void setGameId(String gameId) {
        this.gameId = gameId;
    }

    public String getGiftId() {
        return giftId;
    }

    public void setGiftId(String giftId) {
        this.giftId = giftId;
    }

    public String getItems() {
        return items;
    }

    public void setItems(String items) {
        this.items = items;
    }

    public String getJinzuanLevel() {
        return jinzuanLevel;
    }

    public void setJinzuanLevel(String jinzuanLevel) {
        this.jinzuanLevel = jinzuanLevel;
    }

    public String getInputBy() {
        return inputBy;
    }

    public void setInputBy(String inputBy) {
        this.inputBy = inputBy;
    }

    public String getInputTime() {
        return inputTime;
    }

    public void setInputTime(String inputTime) {
        this.inputTime = inputTime;
    }

    public String getEditBy() {
        return editBy;
    }

    public void setEditBy(String editBy) {
        this.editBy = editBy;
    }

    public String getEditTime() {
        return editTime;
    }

    public void setEditTime(String editTime) {
        this.editTime = editTime;
    }


}
